var group__kernel__classes3 =
[
    [ "CGAL::Aff_transformation_3< Kernel >", "classCGAL_1_1Aff__transformation__3.html", [
      [ "Aff_transformation_3", "classCGAL_1_1Aff__transformation__3.html#ad0f3ff6269c9cea8a2152934ac79fa72", null ],
      [ "Aff_transformation_3", "classCGAL_1_1Aff__transformation__3.html#a41ff5e1505545abad2d0a25b60cc9823", null ],
      [ "Aff_transformation_3", "classCGAL_1_1Aff__transformation__3.html#aebdb37f16ca15276e6708b3e31156a7f", null ],
      [ "Aff_transformation_3", "classCGAL_1_1Aff__transformation__3.html#aa9c9cce6a5b44397a1af5351cebfaaaa", null ],
      [ "Aff_transformation_3", "classCGAL_1_1Aff__transformation__3.html#a8db34fd11059d4674ec383bdf83fd843", null ],
      [ "cartesian", "classCGAL_1_1Aff__transformation__3.html#a0fa2eea1e7662cd702bb786b1647ae39", null ],
      [ "hm", "classCGAL_1_1Aff__transformation__3.html#aa82caae6b1070e23f3ae1d67e48902ce", null ],
      [ "homogeneous", "classCGAL_1_1Aff__transformation__3.html#a8a104e9377e42c7ad8b1dc0a766bcd0b", null ],
      [ "inverse", "classCGAL_1_1Aff__transformation__3.html#a3862ad347ea6ae9f9a96e4f2c37f7e96", null ],
      [ "is_even", "classCGAL_1_1Aff__transformation__3.html#af9e839d67863339be564c7d25d0262b4", null ],
      [ "is_odd", "classCGAL_1_1Aff__transformation__3.html#aa02e2308b59112e9c005239027a867ff", null ],
      [ "is_scaling", "classCGAL_1_1Aff__transformation__3.html#a4645e71937cd6261c79f50e5a38ea0ae", null ],
      [ "is_translation", "classCGAL_1_1Aff__transformation__3.html#ab16fed31c0ca120cd4a9c3ee2faabda3", null ],
      [ "m", "classCGAL_1_1Aff__transformation__3.html#aefd3540947b2b7ca25dcb41ad34bd8c6", null ],
      [ "operator()", "classCGAL_1_1Aff__transformation__3.html#ac84064d450b41282ff073ca585fe6f20", null ],
      [ "operator()", "classCGAL_1_1Aff__transformation__3.html#ac1a7a1228890dd26f621d49f5647c261", null ],
      [ "operator()", "classCGAL_1_1Aff__transformation__3.html#ae38748bb68bb22d5b3eecbeb444a3243", null ],
      [ "operator()", "classCGAL_1_1Aff__transformation__3.html#a6c990af988ac79b4d66fe365b6bf6608", null ],
      [ "operator*", "classCGAL_1_1Aff__transformation__3.html#ad89b5399d03e5c55e9e4e299323eb839", null ],
      [ "operator==", "classCGAL_1_1Aff__transformation__3.html#ab1d37a310cfd6da5fc4b6c02a81125bf", null ],
      [ "transform", "classCGAL_1_1Aff__transformation__3.html#aded12269f3fd897722de6526e71fada6", null ],
      [ "transform", "classCGAL_1_1Aff__transformation__3.html#acc58f141a4f45d620839a90a5a172f25", null ],
      [ "transform", "classCGAL_1_1Aff__transformation__3.html#ab8c7a696627962e170e9f411261632e6", null ],
      [ "transform", "classCGAL_1_1Aff__transformation__3.html#a965340524cadfd53039c4beeb75556b2", null ]
    ] ],
    [ "CGAL::Bbox_3", "classCGAL_1_1Bbox__3.html", [
      [ "Bbox_3", "classCGAL_1_1Bbox__3.html#a75807ebbe9a396b8c3592993e76490df", null ],
      [ "Bbox_3", "classCGAL_1_1Bbox__3.html#aca3d5a6c7a80b4ed24d3c6472a729c60", null ],
      [ "dilate", "classCGAL_1_1Bbox__3.html#a847178c11361c25867381f374fe02983", null ],
      [ "dimension", "classCGAL_1_1Bbox__3.html#a8451a1b0bd16dcced9b8584d4dc99d93", null ],
      [ "max", "classCGAL_1_1Bbox__3.html#a31e0db170d3506e2f4c7dc258ab14ce8", null ],
      [ "min", "classCGAL_1_1Bbox__3.html#a889ef8d49ebea880d9dd57e7b43adc1e", null ],
      [ "operator!=", "classCGAL_1_1Bbox__3.html#ab5266cfd277aea6a7ef3ceab8686108e", null ],
      [ "operator+", "classCGAL_1_1Bbox__3.html#aa21c7a764d07d38cf863c81a31114fce", null ],
      [ "operator+=", "classCGAL_1_1Bbox__3.html#adb5b30cc737e5fde534dc01ab8c0ba3e", null ],
      [ "operator==", "classCGAL_1_1Bbox__3.html#a60c588e8ca31ea7f097a8b211f1382d4", null ],
      [ "scale", "classCGAL_1_1Bbox__3.html#a9b2455c128baae69aaa66963d05ba3b3", null ],
      [ "xmax", "classCGAL_1_1Bbox__3.html#a3f5e323700e1509624a02d151237cc4c", null ],
      [ "xmin", "classCGAL_1_1Bbox__3.html#aab574470a2591f187553ca1166e682e1", null ],
      [ "ymax", "classCGAL_1_1Bbox__3.html#a9d06f61bd89faa841e011ff53edf745f", null ],
      [ "ymin", "classCGAL_1_1Bbox__3.html#a2088e16a1f0a20e011e5b94c2e9c222a", null ],
      [ "zmax", "classCGAL_1_1Bbox__3.html#a98def8b9515f31ded759d781969ddaf6", null ],
      [ "zmin", "classCGAL_1_1Bbox__3.html#a6c55430abc7fda54571cf1075c7f2f8b", null ],
      [ "bbox_3", "classCGAL_1_1Bbox__3.html#a9b38ee256026bdb2d65ba1241c3189af", null ],
      [ "bbox_3", "classCGAL_1_1Bbox__3.html#adf57241c899d9a0868db08113fcc7ab0", null ],
      [ "do_overlap", "group__do__overlap__grp.html#ga6120c76991e6cae48af410ae07c0f2d7", null ]
    ] ],
    [ "CGAL::Circle_3< Kernel >", "classCGAL_1_1Circle__3.html", [
      [ "Circle_3", "classCGAL_1_1Circle__3.html#a0cd4d6bc664480266f32e01702396938", null ],
      [ "Circle_3", "classCGAL_1_1Circle__3.html#aabd7fd3cd82c8662b06216519177e09b", null ],
      [ "Circle_3", "classCGAL_1_1Circle__3.html#a628a1abf985776416995ea8a70820b8d", null ],
      [ "Circle_3", "classCGAL_1_1Circle__3.html#a6cc99798ef4652e9abe5771dd1056706", null ],
      [ "Circle_3", "classCGAL_1_1Circle__3.html#af2d1bbbced58bdd8329f58db645f7ae3", null ],
      [ "Circle_3", "classCGAL_1_1Circle__3.html#a806a827bff86590da42d656361fa7f72", null ],
      [ "approximate_area", "classCGAL_1_1Circle__3.html#a9978d715c99e17691bf18d288538518c", null ],
      [ "approximate_squared_length", "classCGAL_1_1Circle__3.html#a0fcaf1b03b57f332ffa3064ba4f849cc", null ],
      [ "area_divided_by_pi", "classCGAL_1_1Circle__3.html#ac273e4679946f5c8ad46ecd7ec5c3d89", null ],
      [ "bbox", "classCGAL_1_1Circle__3.html#af16e2a5b6a40221f8f6979cd1b4d92b1", null ],
      [ "center", "classCGAL_1_1Circle__3.html#a079e622d8a96bf461cf3a1e9d9c3332b", null ],
      [ "diametral_sphere", "classCGAL_1_1Circle__3.html#a11a78143a91b99d7d133b2d8ee6366d9", null ],
      [ "has_on", "classCGAL_1_1Circle__3.html#a8c7bf1d288a484b562ef0ecfc26f1ac3", null ],
      [ "squared_length_divided_by_pi_square", "classCGAL_1_1Circle__3.html#a76c7c6bce3c8ba764998573a5dbe1ff5", null ],
      [ "squared_radius", "classCGAL_1_1Circle__3.html#a0c3be69dd166a981c1777bcc2f41a9f5", null ],
      [ "supporting_plane", "classCGAL_1_1Circle__3.html#a5d4a043b4adb7a8af38fa0aa4d15292a", null ],
      [ "operator!=", "classCGAL_1_1Circle__3.html#acb73994d5bba1e2c44d92c2c9fadb2c7", null ],
      [ "operator==", "classCGAL_1_1Circle__3.html#a505f603bd66859d13800dee107cdab40", null ]
    ] ],
    [ "CGAL::Direction_3< Kernel >", "classCGAL_1_1Direction__3.html", [
      [ "Direction_3", "classCGAL_1_1Direction__3.html#ae968b98a6d1907fc4536ae933702beb9", null ],
      [ "Direction_3", "classCGAL_1_1Direction__3.html#a12035323074ff7277c14571860e0562f", null ],
      [ "Direction_3", "classCGAL_1_1Direction__3.html#a995a23ddad55782ce12515eaf5dabf36", null ],
      [ "Direction_3", "classCGAL_1_1Direction__3.html#a03bef2eed992c6f471a6faf504eb7f98", null ],
      [ "Direction_3", "classCGAL_1_1Direction__3.html#aff3e47ec346f4bfb27152895db349195", null ],
      [ "delta", "classCGAL_1_1Direction__3.html#a465fc728c19e4590628746530f2ce4aa", null ],
      [ "dx", "classCGAL_1_1Direction__3.html#afa41b9b86b227ce9c57839ccca6359a1", null ],
      [ "dy", "classCGAL_1_1Direction__3.html#a972f72af5c04cce34fe60867112c85e6", null ],
      [ "dz", "classCGAL_1_1Direction__3.html#a902972329d04a79d7b000fa5de989524", null ],
      [ "operator!=", "classCGAL_1_1Direction__3.html#a0631a69c9e17cd34b5353305e2a4bec9", null ],
      [ "operator-", "classCGAL_1_1Direction__3.html#a66eab86bf2b1cfa823a19c127a6ac8ad", null ],
      [ "operator==", "classCGAL_1_1Direction__3.html#a1443fb76690b638516392fbe58651392", null ],
      [ "transform", "classCGAL_1_1Direction__3.html#a1e13cf81d9e7d056ca8a52dc1f1968a9", null ],
      [ "vector", "classCGAL_1_1Direction__3.html#a44fc6bd06bc3eb4b142ff33f2ae1610e", null ]
    ] ],
    [ "CGAL::Iso_cuboid_3< Kernel >", "classCGAL_1_1Iso__cuboid__3.html", [
      [ "Iso_cuboid_3", "classCGAL_1_1Iso__cuboid__3.html#a869572a36c26e30f6adf41c803c7ada7", null ],
      [ "Iso_cuboid_3", "classCGAL_1_1Iso__cuboid__3.html#af5fa5ab21de62a1dd41b3e18f223ec8f", null ],
      [ "Iso_cuboid_3", "classCGAL_1_1Iso__cuboid__3.html#af7ed29ca29bdea72383911157c7be1db", null ],
      [ "Iso_cuboid_3", "classCGAL_1_1Iso__cuboid__3.html#aefd1b29f6441877fee68befc8871205c", null ],
      [ "Iso_cuboid_3", "classCGAL_1_1Iso__cuboid__3.html#a7e2ba8aca0bb6a8e13dab91cf790df1e", null ],
      [ "bbox", "classCGAL_1_1Iso__cuboid__3.html#ac700512815bc067d3eca71a852b34878", null ],
      [ "bounded_side", "classCGAL_1_1Iso__cuboid__3.html#a6b1c54b6a907a4ad9ca4b9d7692252ac", null ],
      [ "has_on_boundary", "classCGAL_1_1Iso__cuboid__3.html#ad4ac68a8945d829b2f6745d7ffcd40fd", null ],
      [ "has_on_bounded_side", "classCGAL_1_1Iso__cuboid__3.html#a74153da56a7bbf586348dca842f09907", null ],
      [ "has_on_unbounded_side", "classCGAL_1_1Iso__cuboid__3.html#aedc1436fdf3bd6b6a5c99209a8ab9af6", null ],
      [ "is_degenerate", "classCGAL_1_1Iso__cuboid__3.html#a264eedc4b1ef9e4d109aebfb03b7d8f9", null ],
      [ "max", "classCGAL_1_1Iso__cuboid__3.html#a81ba47c298f7133e92100f22af5db21a", null ],
      [ "max_coord", "classCGAL_1_1Iso__cuboid__3.html#aa6da9e4f9ec5a9d3bf1f9f1b3b06dfdd", null ],
      [ "min", "classCGAL_1_1Iso__cuboid__3.html#aa5b0b305aaae70450e0c4b716e320d4a", null ],
      [ "min_coord", "classCGAL_1_1Iso__cuboid__3.html#a967d3fc5d0befaae18608cf957ba233c", null ],
      [ "operator!=", "classCGAL_1_1Iso__cuboid__3.html#a84393d44bcfc61cd9b9176072c17dc75", null ],
      [ "operator==", "classCGAL_1_1Iso__cuboid__3.html#abb73f9592a7ec439095b9fc074b18982", null ],
      [ "operator[]", "classCGAL_1_1Iso__cuboid__3.html#ad67df4382bb5206431a20032b1addcb2", null ],
      [ "transform", "classCGAL_1_1Iso__cuboid__3.html#a27c9aee7545fb46779a7bb74307bec30", null ],
      [ "vertex", "classCGAL_1_1Iso__cuboid__3.html#a1675802c82c458ed9342f83062b20818", null ],
      [ "volume", "classCGAL_1_1Iso__cuboid__3.html#a316029c1f67be20558331ffad17a3482", null ],
      [ "xmax", "classCGAL_1_1Iso__cuboid__3.html#a30983fe26addccdb42bbcbcb46bb7384", null ],
      [ "xmin", "classCGAL_1_1Iso__cuboid__3.html#acbd1215e4c1076219e559ed27fa99cfd", null ],
      [ "ymax", "classCGAL_1_1Iso__cuboid__3.html#aef75ce5e4cf75fa0e625ef6ddb7ac23a", null ],
      [ "ymin", "classCGAL_1_1Iso__cuboid__3.html#a40e43f5d0d58fa4d98069adec93b7f06", null ],
      [ "zmax", "classCGAL_1_1Iso__cuboid__3.html#aadb7ae0ec452f77931ecbd6c1924f75a", null ],
      [ "zmin", "classCGAL_1_1Iso__cuboid__3.html#a11230b4e96237a117f285199467b7f66", null ]
    ] ],
    [ "CGAL::Line_3< Kernel >", "classCGAL_1_1Line__3.html", [
      [ "Line_3", "classCGAL_1_1Line__3.html#a1542d153be7231ce25a1a8551b2943ef", null ],
      [ "Line_3", "classCGAL_1_1Line__3.html#ac7ab2d5eaa9ff0fff4f510f82da89be1", null ],
      [ "Line_3", "classCGAL_1_1Line__3.html#a73a4a02de85f7d4c9c6f18e867b539a5", null ],
      [ "Line_3", "classCGAL_1_1Line__3.html#a4ec54cb066d0c9175c00b025295b3cdf", null ],
      [ "Line_3", "classCGAL_1_1Line__3.html#a6264a716f4106e6b0ad2882f85ea7f78", null ],
      [ "direction", "classCGAL_1_1Line__3.html#a827a73129ea2efa21a103bf3b1d1250e", null ],
      [ "has_on", "classCGAL_1_1Line__3.html#aaedd8bfff064ff433efa791a8437a3e9", null ],
      [ "is_degenerate", "classCGAL_1_1Line__3.html#a4352767646919fa252b930f53d4d0405", null ],
      [ "operator!=", "classCGAL_1_1Line__3.html#aa65a460a63d094c659b96245a7f2c132", null ],
      [ "operator==", "classCGAL_1_1Line__3.html#a211538bafc8ddf783904fa8a185f558e", null ],
      [ "opposite", "classCGAL_1_1Line__3.html#a1cf7c68d4a7483664e81193842b4fdd4", null ],
      [ "perpendicular_plane", "classCGAL_1_1Line__3.html#a147867b3bfbb2055fe3f883073e9ab42", null ],
      [ "point", "classCGAL_1_1Line__3.html#a1790d62e0b71253f6198b30716b40953", null ],
      [ "projection", "classCGAL_1_1Line__3.html#a58ddb22a36b5605d41c8e0f222a30f5e", null ],
      [ "to_vector", "classCGAL_1_1Line__3.html#af195e7b7f8f6669136d521ab753be9e8", null ],
      [ "transform", "classCGAL_1_1Line__3.html#aa68906d01285c1abc2aca03906a74186", null ]
    ] ],
    [ "CGAL::Plane_3< Kernel >", "classCGAL_1_1Plane__3.html", [
      [ "Plane_3", "classCGAL_1_1Plane__3.html#af3c70a710a35b054963521ff24d846e2", null ],
      [ "Plane_3", "classCGAL_1_1Plane__3.html#ae4f75b89e91d636eebaf0e0fd1dfd4a9", null ],
      [ "Plane_3", "classCGAL_1_1Plane__3.html#a18b50463614c6eee3a1d6d933a7e4db5", null ],
      [ "Plane_3", "classCGAL_1_1Plane__3.html#a5946d70dfbd251bb0cd9b7685c296e7c", null ],
      [ "Plane_3", "classCGAL_1_1Plane__3.html#ab35accafdeeec101e2943ac1d1d9c90b", null ],
      [ "Plane_3", "classCGAL_1_1Plane__3.html#a21538544cca0e0bf934112d13c406e81", null ],
      [ "Plane_3", "classCGAL_1_1Plane__3.html#a45aa55d07858c36e2a0599b920191f1f", null ],
      [ "Plane_3", "classCGAL_1_1Plane__3.html#af1d75410d3ab52c097092907effb5377", null ],
      [ "a", "classCGAL_1_1Plane__3.html#ae3e4a5dae30e7c0fc55956f081b977b6", null ],
      [ "b", "classCGAL_1_1Plane__3.html#aaaef3942464f136e44a7fad882265466", null ],
      [ "base1", "classCGAL_1_1Plane__3.html#a04225b7706e74a7b6bd24eadf0cfddcd", null ],
      [ "base2", "classCGAL_1_1Plane__3.html#a80330968d52b7be3a29528348ba1b87d", null ],
      [ "c", "classCGAL_1_1Plane__3.html#a60fa2e448ab9d76a724665dc7c781af9", null ],
      [ "d", "classCGAL_1_1Plane__3.html#a97759ecad183f2b21002530624a5797a", null ],
      [ "has_on", "classCGAL_1_1Plane__3.html#a9b71bd0a8b61f27131c4dd7d252fee96", null ],
      [ "has_on", "classCGAL_1_1Plane__3.html#abd05705f493ce3cfaa600defa5600abd", null ],
      [ "has_on", "classCGAL_1_1Plane__3.html#a6d38a5e7a2cb99b8b27e2e8e51d0699a", null ],
      [ "has_on_negative_side", "classCGAL_1_1Plane__3.html#a63bb97c7994ab7b450a276659ad58a48", null ],
      [ "has_on_positive_side", "classCGAL_1_1Plane__3.html#a477af2147c914dd74ef7dedffd6ad958", null ],
      [ "is_degenerate", "classCGAL_1_1Plane__3.html#a105b8bf7edfb4f1396e228cecc8f2749", null ],
      [ "operator!=", "classCGAL_1_1Plane__3.html#a571c800762243fec4dfa19f11d1abd71", null ],
      [ "operator==", "classCGAL_1_1Plane__3.html#afd23b0c86cb18f173aca8a69da1f0c6e", null ],
      [ "opposite", "classCGAL_1_1Plane__3.html#a6f45e84ed5d2a7690f6f3cd77b7c64de", null ],
      [ "oriented_side", "classCGAL_1_1Plane__3.html#a3500f0c6d707bac032fb9fdcbf04cd09", null ],
      [ "orthogonal_direction", "classCGAL_1_1Plane__3.html#afb507696c0120ff5a27b2b0a048a458a", null ],
      [ "orthogonal_vector", "classCGAL_1_1Plane__3.html#a93d0feb722a3b435a2a25524abce3f9d", null ],
      [ "perpendicular_line", "classCGAL_1_1Plane__3.html#ad25c4812b6d35fbf872bad44cebe77eb", null ],
      [ "point", "classCGAL_1_1Plane__3.html#afaf118993632ee104ab42110aaebf47c", null ],
      [ "projection", "classCGAL_1_1Plane__3.html#ab4b3e06410bd35b3eb7aeec95f958c53", null ],
      [ "to_2d", "classCGAL_1_1Plane__3.html#ad5cf19a5d776d8262ddbd2807352e8bb", null ],
      [ "to_3d", "classCGAL_1_1Plane__3.html#af41f582bf26bcb569df14e6ecdea3ea3", null ],
      [ "transform", "classCGAL_1_1Plane__3.html#a427c141c95cef0b764f0980e61c21ab0", null ]
    ] ],
    [ "CGAL::Point_3< Kernel >", "classCGAL_1_1Point__3.html", [
      [ "Cartesian_const_iterator", "classCGAL_1_1Point__3.html#a785cb395833f0ecfb191539a32e96412", null ],
      [ "Point_3", "classCGAL_1_1Point__3.html#a32adf515d5c4b934097f3a7c3dab903f", null ],
      [ "Point_3", "classCGAL_1_1Point__3.html#a726b462d3b0099876d60eaf32b18bfbe", null ],
      [ "Point_3", "classCGAL_1_1Point__3.html#adfccd08ff48024da2e379da8f16e32dc", null ],
      [ "Point_3", "classCGAL_1_1Point__3.html#a7e8f76f245d376b8ae5296999d5c45ae", null ],
      [ "Point_3", "classCGAL_1_1Point__3.html#a0b950997d4dfb65950e417ba447c5bf1", null ],
      [ "Point_3", "classCGAL_1_1Point__3.html#a31fffdf44263f2b57a621daba5df0fd0", null ],
      [ "bbox", "classCGAL_1_1Point__3.html#a65e69167ea5d1a0d5cd1b44bc6b7bc00", null ],
      [ "cartesian", "classCGAL_1_1Point__3.html#a89c276a64d4189eeb3b26c485525b758", null ],
      [ "cartesian_begin", "classCGAL_1_1Point__3.html#a0839f8701cfaa2c50c0a7b53c50d41d8", null ],
      [ "cartesian_end", "classCGAL_1_1Point__3.html#a301c37e21da819ae48a6643e431002a8", null ],
      [ "dimension", "classCGAL_1_1Point__3.html#ae8448565628b97209fe01c9b83b2a4e2", null ],
      [ "homogeneous", "classCGAL_1_1Point__3.html#a18f9a257fa4fa7b31bd2354e05170eaf", null ],
      [ "hw", "classCGAL_1_1Point__3.html#a76acc74680b6019d2066de3a1512e67c", null ],
      [ "hx", "classCGAL_1_1Point__3.html#a479b3235110cb03da01b7326db870bfe", null ],
      [ "hy", "classCGAL_1_1Point__3.html#a82dac5b8e2a728e8c3025b9b66915a37", null ],
      [ "hz", "classCGAL_1_1Point__3.html#a299cb52192bf759338d6582457bd138e", null ],
      [ "operator!=", "classCGAL_1_1Point__3.html#a4822d1d38f976157518fc74f748f6918", null ],
      [ "operator+=", "classCGAL_1_1Point__3.html#a42afebd2bce5d5e4a769fd519ce485ab", null ],
      [ "operator-=", "classCGAL_1_1Point__3.html#a88f9fb15293534b9d0a111967c82821e", null ],
      [ "operator==", "classCGAL_1_1Point__3.html#a5abb4f4a28fbb14fb4701b20498495ca", null ],
      [ "operator[]", "classCGAL_1_1Point__3.html#adcfceb25aacdb8c3986d3d6654e45271", null ],
      [ "transform", "classCGAL_1_1Point__3.html#a5fe71a45905a488c297233e0268a3b23", null ],
      [ "x", "classCGAL_1_1Point__3.html#a49bb8a0c6391066bd91302b20e16eca7", null ],
      [ "y", "classCGAL_1_1Point__3.html#ac50814bb14217280097ebedad0f92586", null ],
      [ "z", "classCGAL_1_1Point__3.html#aa7b6371efb3e7aa179bcfa14c2667f87", null ],
      [ "operator+", "group__Kernel__operator__plus.html#gaf99f17941c49620a9c11c1da0ca6f814", null ],
      [ "operator-", "classCGAL_1_1Point__3.html#a13fbe61503fadf1ea7f66d34652353d1", null ],
      [ "operator-", "group__Kernel__operator__minus.html#gabd87b0cfe45c01a1455da4d992cc44c4", null ],
      [ "operator<", "classCGAL_1_1Point__3.html#aecef3b4737ea139a4b1c03686dfb88d1", null ],
      [ "operator<=", "classCGAL_1_1Point__3.html#a98f6af3334f3450a44343f4768810a20", null ],
      [ "operator>", "classCGAL_1_1Point__3.html#a42ede0762a8ba7de50f5411548aa3dea", null ],
      [ "operator>=", "classCGAL_1_1Point__3.html#aaf0005006e31be506a4b6f818fcaba5b", null ]
    ] ],
    [ "CGAL::Ray_3< Kernel >", "classCGAL_1_1Ray__3.html", [
      [ "Ray_3", "classCGAL_1_1Ray__3.html#ad87728c7cb3783376d75652b3febf27e", null ],
      [ "Ray_3", "classCGAL_1_1Ray__3.html#aa26023c27cde978cff525affa8da308f", null ],
      [ "Ray_3", "classCGAL_1_1Ray__3.html#a5036bfb2e228eb0304fe95964c1b7f67", null ],
      [ "Ray_3", "classCGAL_1_1Ray__3.html#af69e29056c9c4c8fd3733e559da4688f", null ],
      [ "direction", "classCGAL_1_1Ray__3.html#a09826a4a168ebff952498da8de953878", null ],
      [ "has_on", "classCGAL_1_1Ray__3.html#a48ccadbd918c1f5b45febdfb776b82ae", null ],
      [ "is_degenerate", "classCGAL_1_1Ray__3.html#adf2a4f6281ae7dfabc3c7f2c3b9bef7f", null ],
      [ "operator!=", "classCGAL_1_1Ray__3.html#a451d81857ac8ecf6973dac405b08882b", null ],
      [ "operator==", "classCGAL_1_1Ray__3.html#a6ac835de1b9ed9970deadcca273fdc10", null ],
      [ "opposite", "classCGAL_1_1Ray__3.html#a93cc0fb0120ebf55e60cf7dfe32d2249", null ],
      [ "point", "classCGAL_1_1Ray__3.html#ab24a9a573e39ae892ac57e5bc2a68454", null ],
      [ "source", "classCGAL_1_1Ray__3.html#a2f4257b21f4380f6f4bf064dfeed8e3f", null ],
      [ "supporting_line", "classCGAL_1_1Ray__3.html#aafde41299e8eca5e3140d7f5fb22a295", null ],
      [ "to_vector", "classCGAL_1_1Ray__3.html#a93e74fb8845f6f438dcbacef18c8292b", null ],
      [ "transform", "classCGAL_1_1Ray__3.html#ae2ec5ef680f9ac7b2af68622c5538d91", null ]
    ] ],
    [ "CGAL::Segment_3< Kernel >", "classCGAL_1_1Segment__3.html", [
      [ "Segment_3", "classCGAL_1_1Segment__3.html#aff6ed6df35e451f8341b697e2ff395b6", null ],
      [ "bbox", "classCGAL_1_1Segment__3.html#ad320c22d1172fbe38c544cdddbce5258", null ],
      [ "direction", "classCGAL_1_1Segment__3.html#a12d71919befb3b5d19a27db2117ca9f5", null ],
      [ "has_on", "classCGAL_1_1Segment__3.html#aa3ed985e2addf919f6eeba1c929fd40b", null ],
      [ "is_degenerate", "classCGAL_1_1Segment__3.html#ab87b7db9297627c745d1c06cb3492672", null ],
      [ "max", "classCGAL_1_1Segment__3.html#a22bfd1b74be1dd757cfdc92a0b96e2c2", null ],
      [ "min", "classCGAL_1_1Segment__3.html#a32d927b81402e94c18892d66995f8dc4", null ],
      [ "operator!=", "classCGAL_1_1Segment__3.html#aa4e1d8e0e5c088c5bf6769341bfb0188", null ],
      [ "operator==", "classCGAL_1_1Segment__3.html#a8112f4621b334b119b1176241397a21c", null ],
      [ "operator[]", "classCGAL_1_1Segment__3.html#a7133a8d8662623c4d6e75e7a7f89287c", null ],
      [ "opposite", "classCGAL_1_1Segment__3.html#a4ce4f6a8affa8b6514dfb4cef510c5e0", null ],
      [ "point", "classCGAL_1_1Segment__3.html#a1e9efc24d4a6b4ebf226942e6c0465e0", null ],
      [ "source", "classCGAL_1_1Segment__3.html#ae62f06fc5663553958b6ac6e43a1f2b2", null ],
      [ "squared_length", "classCGAL_1_1Segment__3.html#a6537e55b5ea951df2e233334efa03eeb", null ],
      [ "supporting_line", "classCGAL_1_1Segment__3.html#a387ee63bbf54df75cf5848f9aa693eae", null ],
      [ "target", "classCGAL_1_1Segment__3.html#a2c1836447f8d482a3bb532f6411172c8", null ],
      [ "to_vector", "classCGAL_1_1Segment__3.html#a20d5c4bb7c9ad6a9a7ad034fc56587fb", null ],
      [ "transform", "classCGAL_1_1Segment__3.html#a03ff6d93bdecbb6e19bb781851726647", null ],
      [ "vertex", "classCGAL_1_1Segment__3.html#aaa13a9c1657c0c7fc63881862e6e55b1", null ]
    ] ],
    [ "CGAL::Sphere_3< Kernel >", "classCGAL_1_1Sphere__3.html", [
      [ "Sphere_3", "classCGAL_1_1Sphere__3.html#afaa9b613520cfde8fbd53c643c9cf921", null ],
      [ "Sphere_3", "classCGAL_1_1Sphere__3.html#a258421fe590a1fc492e518657f936c3d", null ],
      [ "Sphere_3", "classCGAL_1_1Sphere__3.html#a6306f35aef828d87342ce5f40fce086f", null ],
      [ "Sphere_3", "classCGAL_1_1Sphere__3.html#a74ef3da6618b4c6d93ea59bff3db6291", null ],
      [ "Sphere_3", "classCGAL_1_1Sphere__3.html#a9144992b5e0f92a500461b5ebed78e9b", null ],
      [ "Sphere_3", "classCGAL_1_1Sphere__3.html#aa9b2577a2c9cb9bea94203c2864df711", null ],
      [ "bbox", "classCGAL_1_1Sphere__3.html#add19b579062be36f8cc5cd4a19fbfd0d", null ],
      [ "bounded_side", "classCGAL_1_1Sphere__3.html#a2d9e0d2c5935417158b9a01e9e3df81c", null ],
      [ "center", "classCGAL_1_1Sphere__3.html#a3b87bca471e46cff11858474a7a97999", null ],
      [ "has_on", "classCGAL_1_1Sphere__3.html#a2bb006a5140a1bfdc8e6026c6f4ac5a7", null ],
      [ "has_on", "classCGAL_1_1Sphere__3.html#af8267bffaad6c16d337c05c8a65f583b", null ],
      [ "has_on_boundary", "classCGAL_1_1Sphere__3.html#aa03e57f82d680c541ca9680b098dea4e", null ],
      [ "has_on_bounded_side", "classCGAL_1_1Sphere__3.html#a3cb3da4ac0d084f139736275ae8d2838", null ],
      [ "has_on_negative_side", "classCGAL_1_1Sphere__3.html#a9b0d1558cb06b537f920ab9b564e6cac", null ],
      [ "has_on_positive_side", "classCGAL_1_1Sphere__3.html#a2bb910c9c18714d140bba8f8438614a8", null ],
      [ "has_on_unbounded_side", "classCGAL_1_1Sphere__3.html#a15f7a6a22b0c5eb422c290a87c785229", null ],
      [ "is_degenerate", "classCGAL_1_1Sphere__3.html#a50558a040bf482f33cfe72a279b1c28c", null ],
      [ "operator!=", "classCGAL_1_1Sphere__3.html#a1eb1c79c67d3eec0c2c4fbb6edbbb151", null ],
      [ "operator==", "classCGAL_1_1Sphere__3.html#ac81c5170344e325414da020f269a022e", null ],
      [ "opposite", "classCGAL_1_1Sphere__3.html#a6203b9f4a4afeac40758499e1aec9f6b", null ],
      [ "orientation", "classCGAL_1_1Sphere__3.html#aa8e405d3fc8cd2e882dc9a224a70ccb4", null ],
      [ "oriented_side", "classCGAL_1_1Sphere__3.html#a84be404730bc31d1dff7b508b60d4e7f", null ],
      [ "orthogonal_transform", "classCGAL_1_1Sphere__3.html#ab35934ad405d5627f17504959fa60bbf", null ],
      [ "squared_radius", "classCGAL_1_1Sphere__3.html#a813c19ce7f99b0ad3237f8d13cbefcd5", null ]
    ] ],
    [ "CGAL::Tetrahedron_3< Kernel >", "classCGAL_1_1Tetrahedron__3.html", [
      [ "Tetrahedron_3", "classCGAL_1_1Tetrahedron__3.html#ada967f8a0fbb0fd8539991512fa6155b", null ],
      [ "bbox", "classCGAL_1_1Tetrahedron__3.html#ae418873464cc2faffb1b9c09ab31eda2", null ],
      [ "bounded_side", "classCGAL_1_1Tetrahedron__3.html#a4bee1e1f8e41347ecfef763c733addf2", null ],
      [ "has_on_boundary", "classCGAL_1_1Tetrahedron__3.html#a97251dcb34a634986d2ea2f60adef97e", null ],
      [ "has_on_bounded_side", "classCGAL_1_1Tetrahedron__3.html#a213ed000e8b7b7d4b2cd4c55b3f918d6", null ],
      [ "has_on_negative_side", "classCGAL_1_1Tetrahedron__3.html#acd3e3d1368a9b106c88c93326ddb68df", null ],
      [ "has_on_positive_side", "classCGAL_1_1Tetrahedron__3.html#a1f1bea031cbd712a8d628846de0c29a1", null ],
      [ "has_on_unbounded_side", "classCGAL_1_1Tetrahedron__3.html#a9eb82b5ab1dcad86cc19bc512637c53f", null ],
      [ "is_degenerate", "classCGAL_1_1Tetrahedron__3.html#ac4b53263b3552d972bb2e0538e34fe9a", null ],
      [ "operator!=", "classCGAL_1_1Tetrahedron__3.html#a2ad1172420c2e5a83b91440698ba5cae", null ],
      [ "operator==", "classCGAL_1_1Tetrahedron__3.html#a15d31ed2f49dcf90fd67716a0cfddcf6", null ],
      [ "operator[]", "classCGAL_1_1Tetrahedron__3.html#a6c9f9d8f894107e793f114cb3226b26c", null ],
      [ "orientation", "classCGAL_1_1Tetrahedron__3.html#abfae4f8209a06342ccc8aa9f83e2661a", null ],
      [ "oriented_side", "classCGAL_1_1Tetrahedron__3.html#a2552ae8d2679851625760c58f9b08601", null ],
      [ "transform", "classCGAL_1_1Tetrahedron__3.html#a3d0cf38ceea4233fe9587a40c3317e8f", null ],
      [ "vertex", "classCGAL_1_1Tetrahedron__3.html#abf606f69128eb996dc6b29c57462fec0", null ],
      [ "volume", "classCGAL_1_1Tetrahedron__3.html#a19ca0997025c6f7f721b0d12b1c9df72", null ]
    ] ],
    [ "CGAL::Triangle_3< Kernel >", "classCGAL_1_1Triangle__3.html", [
      [ "Triangle_3", "classCGAL_1_1Triangle__3.html#afdbaa1d6cb37fc9ead83e0df947a8e18", null ],
      [ "bbox", "classCGAL_1_1Triangle__3.html#ac08d19415006fd6c1cfc67db7172967f", null ],
      [ "has_on", "classCGAL_1_1Triangle__3.html#a9a44d2c09ad7019d75319485586d9b3e", null ],
      [ "is_degenerate", "classCGAL_1_1Triangle__3.html#ae758d9c6afaf9f8cdcb891112217b425", null ],
      [ "operator!=", "classCGAL_1_1Triangle__3.html#ac5f2aef4e4a72b0842e987761bd62aa7", null ],
      [ "operator==", "classCGAL_1_1Triangle__3.html#ae43e3a54e93515b2132f7f7398f1b5c8", null ],
      [ "operator[]", "classCGAL_1_1Triangle__3.html#abd870d17250fc3b8b6602f570c13102f", null ],
      [ "squared_area", "classCGAL_1_1Triangle__3.html#ad8d67a5a793d6041a78e09d2bf456d9e", null ],
      [ "supporting_plane", "classCGAL_1_1Triangle__3.html#aa7474f31c2d932b89d4cbed08ead8c1a", null ],
      [ "transform", "classCGAL_1_1Triangle__3.html#a9cba1f49edc2a7cb667309fa35cb773e", null ],
      [ "vertex", "classCGAL_1_1Triangle__3.html#a284729f483cb913b82c95228c3a9b3b6", null ]
    ] ],
    [ "CGAL::Vector_3< Kernel >", "classCGAL_1_1Vector__3.html", [
      [ "Cartesian_const_iterator", "classCGAL_1_1Vector__3.html#a18250e85f4a6e3f530bdc5e2ce8faaab", null ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html#a7847f1afb918e3f45f79032ae67f49cc", null ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html#a5c8ea293bcca4479e7425f93ed8c687c", null ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html#a7efaded0de78d319f0eddfb844f35eaa", null ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html#ac552c4322f4d680b6af3bf3024aa0021", null ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html#ab2e0bb10be345d03fb9d50e891e27ad5", null ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html#a2cf106559e91de597ef2f7c345d8fe35", null ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html#ae2ac5be9ac9f893d6e4f197842482210", null ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html#ab767ede0eced6a090c20160939267ecf", null ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html#a0e4d1f3955c8010bcfc8bb2993f9aeea", null ],
      [ "cartesian", "classCGAL_1_1Vector__3.html#a5543aeb3b847342c0ba6a2a600d3eb87", null ],
      [ "cartesian_begin", "classCGAL_1_1Vector__3.html#ac7436015d2a39d8b23f4b138d5e0dbea", null ],
      [ "cartesian_end", "classCGAL_1_1Vector__3.html#a7ef5d0986e595425ce057a51cd0b77e9", null ],
      [ "dimension", "classCGAL_1_1Vector__3.html#a34403fbfdbdcf7763f8870eace5de74a", null ],
      [ "direction", "classCGAL_1_1Vector__3.html#a74062eec37535328f51a037f160b720e", null ],
      [ "homogeneous", "classCGAL_1_1Vector__3.html#a240817ab55ea65123f3afd9f29532299", null ],
      [ "hw", "classCGAL_1_1Vector__3.html#a506763717c95b3a3b58e03f72ae4121a", null ],
      [ "hx", "classCGAL_1_1Vector__3.html#a1e32afdea3bacdf938380a825089e335", null ],
      [ "hy", "classCGAL_1_1Vector__3.html#afb487cc50d61554b992c6d792497126f", null ],
      [ "hz", "classCGAL_1_1Vector__3.html#a5a508d16e207433116656468dc5bb406", null ],
      [ "operator!=", "classCGAL_1_1Vector__3.html#a9f79abd0a0ec888a17f4781ca7356803", null ],
      [ "operator*", "classCGAL_1_1Vector__3.html#a5f8242b5e51eb8d21552427e262c02d3", null ],
      [ "operator*=", "classCGAL_1_1Vector__3.html#ab1137c178abbc3d727da3472f70210a1", null ],
      [ "operator+", "classCGAL_1_1Vector__3.html#af71303dd185235c30aca5cbf27b337a8", null ],
      [ "operator+=", "classCGAL_1_1Vector__3.html#ab07a60ea16d8ed25afc023919feb4bc5", null ],
      [ "operator-", "classCGAL_1_1Vector__3.html#a1f63d3939672857f3fad2d28500d95c8", null ],
      [ "operator-", "classCGAL_1_1Vector__3.html#a6698c704876ebfddbb49e17e8273f7fb", null ],
      [ "operator-=", "classCGAL_1_1Vector__3.html#a3a78451e5d4d9a4e31bd4fad68b2d57c", null ],
      [ "operator/", "classCGAL_1_1Vector__3.html#a0238c8613cab03d988f6f98c8e0a3ec1", null ],
      [ "operator/=", "classCGAL_1_1Vector__3.html#af483ab4cb7a550795784beef528e1a4b", null ],
      [ "operator==", "classCGAL_1_1Vector__3.html#a2e146ae3dd0af3b59ea0ce5f109508ef", null ],
      [ "operator[]", "classCGAL_1_1Vector__3.html#a290e453e8b1e4f010d9e8eaa7bb7b59a", null ],
      [ "squared_length", "classCGAL_1_1Vector__3.html#aaa8a02645a895f1cd7250e560ce73f4f", null ],
      [ "transform", "classCGAL_1_1Vector__3.html#af730fcec11b3e9b43a2d27c25a48f8dc", null ],
      [ "x", "classCGAL_1_1Vector__3.html#ad03593bd198ae08203c10f83363948f6", null ],
      [ "y", "classCGAL_1_1Vector__3.html#a1119ad34b73433b6f06402686da47c92", null ],
      [ "z", "classCGAL_1_1Vector__3.html#a32c741c5eecba04835cb0f1a357d8b04", null ],
      [ "operator*", "group__Kernel__operator__prod.html#gabb1d92af360ae79c4f41376ab8f77563", null ],
      [ "operator*", "group__Kernel__operator__prod.html#gaa09a2f90ca10bea6e225c3a6f2f3f6e7", null ],
      [ "operator*", "group__Kernel__operator__prod.html#gab4c5d9764f9fcd9f0b041fd289e19af3", null ],
      [ "operator*", "group__Kernel__operator__prod.html#ga7a0a1c5cadcf1957129f3af57b8ad0cf", null ]
    ] ],
    [ "CGAL::Weighted_point_3< Kernel >", "classCGAL_1_1Weighted__point__3.html", [
      [ "Cartesian_const_iterator", "classCGAL_1_1Weighted__point__3.html#a7d9f0a8ce99af0e7aadf5b238f9318c6", null ],
      [ "Weighted_point_3", "classCGAL_1_1Weighted__point__3.html#a5f0e3db11485d951617a24a4c5c7cf79", null ],
      [ "Weighted_point_3", "classCGAL_1_1Weighted__point__3.html#acab05748692574b856d3018a68836dd3", null ],
      [ "Weighted_point_3", "classCGAL_1_1Weighted__point__3.html#aa7e10c2349325257ef3a7b4b3d954ee5", null ],
      [ "Weighted_point_3", "classCGAL_1_1Weighted__point__3.html#a13dcafaaeee6cf7c648b70b9e79c1937", null ],
      [ "bbox", "classCGAL_1_1Weighted__point__3.html#a938acff83f9c5f9fbd8986b6572c3cb7", null ],
      [ "cartesian", "classCGAL_1_1Weighted__point__3.html#a9b847793ad7dda2c8448c99c65efe9a0", null ],
      [ "cartesian_begin", "classCGAL_1_1Weighted__point__3.html#ad3085f53f259842ea44bd4912e29ecc5", null ],
      [ "cartesian_end", "classCGAL_1_1Weighted__point__3.html#a894cf356afaeaaabb72e685433beb95f", null ],
      [ "dimension", "classCGAL_1_1Weighted__point__3.html#af2ba8c4e29b2eff3aa82124974f32918", null ],
      [ "homogeneous", "classCGAL_1_1Weighted__point__3.html#ae84de402eb0a3a971e3e6fdb859c55b1", null ],
      [ "hw", "classCGAL_1_1Weighted__point__3.html#af1932444cd78b72722df30ac4b0d5ea7", null ],
      [ "hx", "classCGAL_1_1Weighted__point__3.html#a4fe46e95052c0a77f19e3c1c94de514c", null ],
      [ "hy", "classCGAL_1_1Weighted__point__3.html#a8796f4ec4676ca5253f06b30aa812cab", null ],
      [ "hz", "classCGAL_1_1Weighted__point__3.html#ad33ad551cdfa33747c0b61e998d71b48", null ],
      [ "operator!=", "classCGAL_1_1Weighted__point__3.html#aa38dbc7f77a0c129a956c9c2aad42fe9", null ],
      [ "operator==", "classCGAL_1_1Weighted__point__3.html#a9bac9435713946f30b8d29af9208d9ca", null ],
      [ "operator[]", "classCGAL_1_1Weighted__point__3.html#ad874cb3472dcd0b6a0dc34b8cd962823", null ],
      [ "point", "classCGAL_1_1Weighted__point__3.html#a5aeb270225da0ff64196182055adb588", null ],
      [ "transform", "classCGAL_1_1Weighted__point__3.html#a1074ae95f3061e8e8455335943a45c6c", null ],
      [ "weight", "classCGAL_1_1Weighted__point__3.html#ac404f435d96e0501951a04f10ed99f9b", null ],
      [ "x", "classCGAL_1_1Weighted__point__3.html#a800c4cb31ff246180eec71c92f01ee24", null ],
      [ "y", "classCGAL_1_1Weighted__point__3.html#a874257fe9ecd778dd607898aaededb76", null ],
      [ "z", "classCGAL_1_1Weighted__point__3.html#ab0935eac6f582db5ba34158117f16a22", null ]
    ] ]
];